package ca.carleton.gcrc.couch.onUpload;

import java.io.File;

import ca.carleton.gcrc.couch.client.CouchDesignDocument;

public class UploadWorker {

	private CouchDesignDocument designDocument = null;
	private File mediaDir = null;
	private UploadWorkerThread workerThread = null;
	
	public UploadWorker() {
	}
	
	public CouchDesignDocument getDesignDocument() {
		return designDocument;
	}

	public void setDesignDocument(CouchDesignDocument designDocument) {
		this.designDocument = designDocument;
	}

	public File getMediaDir() {
		return mediaDir;
	}

	public void setMediaDir(File mediaDir) {
		this.mediaDir = mediaDir;
	}

	synchronized public void start() throws Exception {
		if( null == designDocument ) {
			throw new Exception("Design document must be specified for upload worker");
		}
		if( null == mediaDir ) {
			throw new Exception("Media directory must be specified for upload worker");
		}
		if( null != workerThread ) {
			// Already started
			return;
		}
		workerThread = new UploadWorkerThread(designDocument, mediaDir);
		workerThread.start();
	}
	
	synchronized public void stop() throws Exception {
		if( null == workerThread ) {
			return;
		}
		UploadWorkerThread thread = workerThread;
		workerThread = null;

		thread.shutdown();
		thread.join();
	}

	public void stopTimeoutMillis(int millis) throws Exception {
		if( null == workerThread ) {
			return;
		}
		UploadWorkerThread thread = workerThread;
		workerThread = null;

		thread.shutdown();
		thread.join(millis);
		thread.interrupt();
	}
}
